@@ -1,10 +1,10 @@
 from veropt.slurm_support import slurm_set_up
 from veropt.slurm_support import slurm_controller
 
-try:
-    from veropt.slurm_support import run_full_exp_mpi
-except (ImportError, NameError, ModuleNotFoundError):
-    pass
+# try:
+#     from veropt.slurm_support import run_full_exp_mpi
+# except (ImportError, NameError, ModuleNotFoundError):
+#     pass
 
 from veropt.slurm_support.slurm_set_up import set_up, start_opt_run
 from veropt.slurm_support.slurm_controller import cancel_jobs
